Class ExtendedSyntaxBuilder

java.lang.Object
de.odysseus.el.tree.impl.Builder
com.hubspot.jinjava.el.ExtendedSyntaxBuilder
All Implemented Interfaces:
de.odysseus.el.tree.TreeBuilder, Serializable
Direct Known Subclasses:
EagerExtendedSyntaxBuilder

public class ExtendedSyntaxBuilder extends de.odysseus.el.tree.impl.Builder
Syntax extensions for the expression language library - pipe '|' postfix unary operator for applying filters to expressions - positive '+' prefix unary operator for absolute value of numeric - 'is' postfix operator for creating a boolean expression with an expression test function - named function args support (still requires precise order, but accepts syntax of fn(foo=bar, a=b)
See Also:
  • Nested Class Summary

    Nested classes/interfaces inherited from class de.odysseus.el.tree.impl.Builder

    de.odysseus.el.tree.impl.Builder.Feature
  • Constructor Summary

    Constructors
    Constructor
    Description
     
    ExtendedSyntaxBuilder(de.odysseus.el.tree.impl.Builder.Feature... features)
     
  • Method Summary

    Methods inherited from class de.odysseus.el.tree.impl.Builder

    build, equals, hashCode, isEnabled, main

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • ExtendedSyntaxBuilder

      public ExtendedSyntaxBuilder()
    • ExtendedSyntaxBuilder

      public ExtendedSyntaxBuilder(de.odysseus.el.tree.impl.Builder.Feature... features)