Package com.hubspot.jinjava.el.ext
Class AbstractCallableMethod
java.lang.Object
com.hubspot.jinjava.el.ext.AbstractCallableMethod
- Direct Known Subclasses:
MacroFunction
Defines a function which will be called in the context of an interpreter instance. Supports named params with default values, as well as var args.
- Author:
- jstehler
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionAbstractCallableMethod(String name, LinkedHashMap<String, Object> argNamesWithDefaults) -
Method Summary
-
Field Details
-
EVAL_METHOD
-
-
Constructor Details
-
AbstractCallableMethod
-
-
Method Details
-
evaluate
-
doEvaluate
-
getName
-
getArguments
-
getDefaults
-