Package com.hubspot.jinjava.el.ext
Class NamedParameter
java.lang.Object
com.hubspot.jinjava.el.ext.NamedParameter
- All Implemented Interfaces:
PyWrapper,PyishSerializable
-
Field Summary
Fields inherited from interface com.hubspot.jinjava.objects.serialization.PyishSerializable
SELF_WRITER -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription<T extends Appendable & CharSequence>
TappendPyishString(T appendable) Allows for a class to append the custom string representation in Jinjava.getName()getValue()toString()Methods inherited from class java.lang.Object
equals, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.hubspot.jinjava.objects.serialization.PyishSerializable
writePyishSelf
-
Constructor Details
-
NamedParameter
-
-
Method Details
-
getName
-
getValue
-
toString
-
appendPyishString
Description copied from interface:PyishSerializableAllows for a class to append the custom string representation in Jinjava. This method will be used byPyishSerializable.writePyishSelf(JsonGenerator, SerializerProvider)to specify what will be written to the json generator.- Specified by:
appendPyishStringin interfacePyishSerializable- Parameters:
appendable- Appendable to append the pyish string representation to.- Returns:
- The same appendable with an appended result
- Throws:
IOException
-