Class EagerAstMethod

java.lang.Object
de.odysseus.el.tree.impl.ast.AstNode
de.odysseus.el.tree.impl.ast.AstMethod
com.hubspot.jinjava.el.ext.eager.EagerAstMethod
All Implemented Interfaces:
EvalResultHolder, de.odysseus.el.tree.ExpressionNode, de.odysseus.el.tree.Node

public class EagerAstMethod extends de.odysseus.el.tree.impl.ast.AstMethod implements EvalResultHolder
  • Constructor Summary

    Constructors
    Constructor
    Description
    EagerAstMethod(de.odysseus.el.tree.impl.ast.AstProperty property, de.odysseus.el.tree.impl.ast.AstParameters params)
     
  • Method Summary

    Modifier and Type
    Method
    Description
    eval(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context)
     
     
    getPartiallyResolved(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context, DeferredParsingException deferredParsingException, IdentifierPreservationStrategy identifierPreservationStrategy)
    This method is used when we need to reconstruct the method property and params manually.
    boolean
     
    void
    setEvalResult(Object evalResult)
     

    Methods inherited from class de.odysseus.el.tree.impl.ast.AstMethod

    appendStructure, getCardinality, getChild, getMethodInfo, getType, getValueReference, invoke, isLeftValue, isLiteralText, isMethodInvocation, isReadOnly, setValue, toString

    Methods inherited from class de.odysseus.el.tree.impl.ast.AstNode

    getStructuralId, getValue

    Methods inherited from class java.lang.Object

    equals, getClass, hashCode, notify, notifyAll, wait, wait, wait

    Methods inherited from interface com.hubspot.jinjava.el.ext.eager.EvalResultHolder

    checkEvalResultSize, eval
  • Constructor Details

    • EagerAstMethod

      public EagerAstMethod(de.odysseus.el.tree.impl.ast.AstProperty property, de.odysseus.el.tree.impl.ast.AstParameters params)
  • Method Details

    • eval

      public Object eval(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context)
      Overrides:
      eval in class de.odysseus.el.tree.impl.ast.AstMethod
    • getEvalResult

      public Object getEvalResult()
      Specified by:
      getEvalResult in interface EvalResultHolder
    • setEvalResult

      public void setEvalResult(Object evalResult)
      Specified by:
      setEvalResult in interface EvalResultHolder
    • hasEvalResult

      public boolean hasEvalResult()
      Specified by:
      hasEvalResult in interface EvalResultHolder
    • getPartiallyResolved

      public String getPartiallyResolved(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context, DeferredParsingException deferredParsingException, IdentifierPreservationStrategy identifierPreservationStrategy)
      This method is used when we need to reconstruct the method property and params manually. Neither the property or params could be evaluated so we dive into the property and figure out where the DeferredParsingException came from.
      Specified by:
      getPartiallyResolved in interface EvalResultHolder