Package com.hubspot.jinjava.interpret
Interface DeferredValue
-
- All Known Subinterfaces:
PartiallyDeferredValue
- All Known Implementing Classes:
DeferredLazyReference,DeferredLazyReferenceSource,DeferredMacroValueImpl,DeferredValueImpl
public interface DeferredValueMarker object which indicates that the template engine should skip over evaluating this part of the template, if the object is resolved from the context.
-
-
Method Summary
All Methods Static Methods Instance Methods Abstract Methods Modifier and Type Method Description ObjectgetOriginalValue()static DeferredValueinstance()static DeferredValueinstance(Object originalValue)
-
-
-
Method Detail
-
getOriginalValue
Object getOriginalValue()
-
instance
static DeferredValue instance()
-
instance
static DeferredValue instance(Object originalValue)
-
-