Package com.hubspot.jinjava.interpret
package com.hubspot.jinjava.interpret
-
ClassDescriptionImmutable implementation of
ContextConfigurationIF.Builds instances of typeContextConfiguration.Marker object which indicates that the template engine should skip over evaluating this part of the template, if the object is resolved from the context.Exception thrown when attempting to render aDeferredValue.A deferred value which represents that a value was deferred within this context, but it is does not overwrite the actual key in which the original value resides on the context.Immutable implementation ofContextConfigurationIF.ErrorHandlingStrategyIF.Builds instances of typeErrorHandlingStrategy.Container exception thrown when fatal errors are encountered while rendering a template.Exception thrown when `continue` or `break` is called outside of a loopMarker object of a `null` value.An interface for a type of DeferredValue that as a whole is not deferred, but certain attributes or methods within it are deferred.