Annotation Type ELFunction


@Retention(RUNTIME) @Target(METHOD) public @interface ELFunction
Defines that this public static method should be exposed to the expression resolver, with the given name and optional namespace. Note that you can specify a JinjavaInterpreter or Context parameter in your method as the first argument, and it will be passed in.
Author:
jstehler
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
     
  • Optional Element Summary

    Optional Elements
    Modifier and Type
    Optional Element
    Description
     
  • Element Details

    • namespace

      String namespace
      Returns:
      The namespace to define the function in (e.g. 'fn' would expose 'foo' as: 'fn:foo()')
      Default:
      ""
    • value

      String value
      Returns:
      The local name to expose this function as