Package com.hubspot.jinjava.mode
Class NonRevertingEagerExecutionMode
- java.lang.Object
-
- com.hubspot.jinjava.mode.EagerExecutionMode
-
- com.hubspot.jinjava.mode.NonRevertingEagerExecutionMode
-
- All Implemented Interfaces:
ExecutionMode
public class NonRevertingEagerExecutionMode extends EagerExecutionMode
-
-
Field Summary
-
Fields inherited from class com.hubspot.jinjava.mode.EagerExecutionMode
STATIC_META_CONTEXT_VARIABLES
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ExecutionModeinstance()booleanuseEagerContextReverting()This will determine if the entire context can be reverted or if only the current scope can get reverted.-
Methods inherited from class com.hubspot.jinjava.mode.EagerExecutionMode
isPreserveRawTags, prepareContext, useEagerParser
-
-
-
-
Method Detail
-
instance
public static ExecutionMode instance()
-
useEagerContextReverting
public boolean useEagerContextReverting()
Description copied from interface:ExecutionModeThis will determine if the entire context can be reverted or if only the current scope can get reverted. A snapshot of the context is created so it is expensive to do so with the entire context, but less expensive to only do that with the current scope- Specified by:
useEagerContextRevertingin interfaceExecutionMode- Overrides:
useEagerContextRevertingin classEagerExecutionMode- Returns:
- whether the entire context (true) or just the current scope (false) will have a snapshot created to allow reverting of modified values in deferred execution mode.
-
-