Class SnakeCaseAccessibleMap
java.lang.Object
com.google.common.collect.ForwardingObject
com.google.common.collect.ForwardingMap<String,Object>
com.hubspot.jinjava.objects.collections.PyMap
com.hubspot.jinjava.objects.collections.SnakeCaseAccessibleMap
- All Implemented Interfaces:
PyWrapper,PyishSerializable,Map<String,Object>
-
Nested Class Summary
-
Field Summary
Fields inherited from interface com.hubspot.jinjava.objects.serialization.PyishSerializable
SELF_WRITER -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription<T extends Appendable & CharSequence>
TappendPyishString(T appendable) Allows for a class to append the custom string representation in Jinjava.Methods inherited from class com.hubspot.jinjava.objects.collections.PyMap
get, hashCode, items, keys, put, putAll, toMap, toString, updateMethods inherited from class com.google.common.collect.ForwardingMap
clear, containsKey, containsValue, entrySet, equals, isEmpty, keySet, remove, size, valuesMethods inherited from interface java.util.Map
compute, computeIfAbsent, computeIfPresent, forEach, getOrDefault, merge, putIfAbsent, remove, replace, replace, replaceAllMethods inherited from interface com.hubspot.jinjava.objects.serialization.PyishSerializable
writePyishSelf
-
Constructor Details
-
SnakeCaseAccessibleMap
-
-
Method Details
-
get
-
appendPyishString
Description copied from interface:PyishSerializableAllows for a class to append the custom string representation in Jinjava. This method will be used byPyishSerializable.writePyishSelf(JsonGenerator, SerializerProvider)to specify what will be written to the json generator.- Specified by:
appendPyishStringin interfacePyishSerializable- Parameters:
appendable- Appendable to append the pyish string representation to.- Returns:
- The same appendable with an appended result
- Throws:
IOException
-