Package com.hubspot.jinjava.objects
-
Interface Summary Interface Description PyWrapper Marker indicating an object is a python wrapper interface. -
Class Summary Class Description DummyObject Namespace SafeString
| Interface | Description |
|---|---|
| PyWrapper |
Marker indicating an object is a python wrapper interface.
|
| Class | Description |
|---|---|
| DummyObject | |
| Namespace | |
| SafeString |