Uses of Class
com.hubspot.jinjava.tree.Node
Packages that use Node
Package
Description
-
Uses of Node in com.hubspot.jinjava
Methods in com.hubspot.jinjava that return types with arguments of type NodeMethod parameters in com.hubspot.jinjava with type arguments of type NodeModifier and TypeMethodDescriptionJinjavaConfig.Builder.withNodePreProcessor(BiConsumer<Node, JinjavaInterpreter> nodePreProcessor) Deprecated. -
Uses of Node in com.hubspot.jinjava.el
Methods in com.hubspot.jinjava.el that return types with arguments of type NodeModifier and TypeMethodDescriptionJinjavaProcessors.getNodePostProcessor()JinjavaProcessors.getNodePreProcessor()Methods in com.hubspot.jinjava.el with parameters of type NodeModifier and TypeMethodDescriptionvoidJinjavaNodePreProcessor.accept(Node node, JinjavaInterpreter interpreter) voidJinjavaNodeProcessor.accept(Node node, JinjavaInterpreter interpreter) Method parameters in com.hubspot.jinjava.el with type arguments of type NodeModifier and TypeMethodDescriptionJinjavaProcessors.Builder.withNodePostProcessor(BiConsumer<Node, JinjavaInterpreter> processor) JinjavaProcessors.Builder.withNodePreProcessor(BiConsumer<Node, JinjavaInterpreter> processor) -
Uses of Node in com.hubspot.jinjava.interpret
Methods in com.hubspot.jinjava.interpret that return NodeMethods in com.hubspot.jinjava.interpret that return types with arguments of type NodeMethods in com.hubspot.jinjava.interpret with parameters of type NodeModifier and TypeMethodDescriptionvoidJinjavaInterpreter.addExtendParentRoot(Node root) voidContext.handleDeferredNode(Node node) Render the given root node, processing extend parents.Render the given root node with an option to process extend parents.voidContext.setCurrentNode(Node currentNode) Method parameters in com.hubspot.jinjava.interpret with type arguments of type Node -
Uses of Node in com.hubspot.jinjava.lib.fn
Constructor parameters in com.hubspot.jinjava.lib.fn with type arguments of type NodeModifierConstructorDescriptionMacroFunction(List<Node> content, String name, LinkedHashMap<String, Object> argNamesWithDefaults, boolean caller, Context localContextScope, int lineNumber, int startPosition) -
Uses of Node in com.hubspot.jinjava.lib.fn.eager
Constructor parameters in com.hubspot.jinjava.lib.fn.eager with type arguments of type NodeModifierConstructorDescriptionEagerMacroFunction(List<Node> content, String name, LinkedHashMap<String, Object> argNamesWithDefaults, boolean caller, Context localContextScope, int lineNumber, int startPosition) -
Uses of Node in com.hubspot.jinjava.lib.tag
Methods in com.hubspot.jinjava.lib.tag that return types with arguments of type NodeModifier and TypeMethodDescriptionstatic AutoCloseableSupplier<Node> ImportTag.parseTemplateAsNode(JinjavaInterpreter interpreter, String templateFile) Methods in com.hubspot.jinjava.lib.tag with parameters of type NodeModifier and TypeMethodDescriptionstatic voidImportTag.handleDeferredNodesDuringImport(Node node, String contextVar, Map<String, Object> childBindings, JinjavaInterpreter child, JinjavaInterpreter interpreter) RawTag.renderNodeRaw(Node n) -
Uses of Node in com.hubspot.jinjava.tree
Subclasses of Node in com.hubspot.jinjava.treeModifier and TypeClassDescriptionclassclassclassclassMethods in com.hubspot.jinjava.tree that return NodeMethods in com.hubspot.jinjava.tree that return types with arguments of type NodeMethods in com.hubspot.jinjava.tree with parameters of type NodeMethod parameters in com.hubspot.jinjava.tree with type arguments of type Node -
Uses of Node in com.hubspot.jinjava.tree.output
Methods in com.hubspot.jinjava.tree.output that return types with arguments of type NodeConstructor parameters in com.hubspot.jinjava.tree.output with type arguments of type Node -
Uses of Node in com.hubspot.jinjava.util
Methods in com.hubspot.jinjava.util with parameters of type NodeModifier and TypeMethodDescriptionDeferredValueUtils.findAndMarkDeferredProperties(Context context, Node newNode) static Set<com.hubspot.jinjava.util.DeferredValueUtils.DeferredTag> DeferredValueUtils.getDeferredTagsRecursively(Node deferredNode)
JinjavaConfig.getProcessors()andJinjavaProcessors.getNodePreProcessor()