Package com.hubspot.jinjava.util
Class HelperStringTokenizer
Whitespace and comma as separator quote to accept them as normal char
- Author:
- fangchq
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionsplitComma(boolean onOrOff) use Comma as token split or not true use it; false don't use it.Methods inherited from class com.google.common.collect.AbstractIterator
hasNext, next, peekMethods inherited from class com.google.common.collect.UnmodifiableIterator
removeMethods inherited from class java.lang.Object
equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface java.util.Iterator
forEachRemaining
-
Constructor Details
-
HelperStringTokenizer
-
-
Method Details
-
splitComma
use Comma as token split or not true use it; false don't use it.- Parameters:
onOrOff- flag to indicate whether or not to split on commas- Returns:
- this instance for method chaining
-
allTokens
-