Package com.hubspot.jinjava.el.ext.eager
Class EagerAstMethod
java.lang.Object
de.odysseus.el.tree.impl.ast.AstNode
de.odysseus.el.tree.impl.ast.AstMethod
com.hubspot.jinjava.el.ext.eager.EagerAstMethod
- All Implemented Interfaces:
EvalResultHolder,de.odysseus.el.tree.ExpressionNode,de.odysseus.el.tree.Node
public class EagerAstMethod
extends de.odysseus.el.tree.impl.ast.AstMethod
implements EvalResultHolder
-
Constructor Summary
ConstructorsConstructorDescriptionEagerAstMethod(de.odysseus.el.tree.impl.ast.AstProperty property, de.odysseus.el.tree.impl.ast.AstParameters params) -
Method Summary
Modifier and TypeMethodDescriptioneval(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context) getPartiallyResolved(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context, DeferredParsingException deferredParsingException, IdentifierPreservationStrategy identifierPreservationStrategy) This method is used when we need to reconstruct the method property and params manually.booleanvoidsetEvalResult(Object evalResult) Methods inherited from class de.odysseus.el.tree.impl.ast.AstMethod
appendStructure, getCardinality, getChild, getMethodInfo, getType, getValueReference, invoke, isLeftValue, isLiteralText, isMethodInvocation, isReadOnly, setValue, toStringMethods inherited from class de.odysseus.el.tree.impl.ast.AstNode
getStructuralId, getValueMethods inherited from class java.lang.Object
equals, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.hubspot.jinjava.el.ext.eager.EvalResultHolder
checkEvalResultSize, eval
-
Constructor Details
-
EagerAstMethod
public EagerAstMethod(de.odysseus.el.tree.impl.ast.AstProperty property, de.odysseus.el.tree.impl.ast.AstParameters params)
-
-
Method Details
-
eval
- Overrides:
evalin classde.odysseus.el.tree.impl.ast.AstMethod
-
getEvalResult
- Specified by:
getEvalResultin interfaceEvalResultHolder
-
setEvalResult
- Specified by:
setEvalResultin interfaceEvalResultHolder
-
hasEvalResult
public boolean hasEvalResult()- Specified by:
hasEvalResultin interfaceEvalResultHolder
-
getPartiallyResolved
public String getPartiallyResolved(de.odysseus.el.tree.Bindings bindings, javax.el.ELContext context, DeferredParsingException deferredParsingException, IdentifierPreservationStrategy identifierPreservationStrategy) This method is used when we need to reconstruct the method property and params manually. Neither the property or params could be evaluated so we dive into the property and figure out where the DeferredParsingException came from.- Specified by:
getPartiallyResolvedin interfaceEvalResultHolder
-