Class DeferredValue


  • public class DeferredValue
    extends Object
    Marker object which indicates that the template engine should skip over evaluating this part of the template, if the object is resolved from the context.