Package com.hubspot.jinjava.interpret
Class DeferredValue
- java.lang.Object
-
- com.hubspot.jinjava.interpret.DeferredValue
-
public class DeferredValue extends Object
Marker object which indicates that the template engine should skip over evaluating this part of the template, if the object is resolved from the context.
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description ObjectgetOriginalValue()static DeferredValueinstance()static DeferredValueinstance(Object originalValue)
-
-
-
Method Detail
-
getOriginalValue
public Object getOriginalValue()
-
instance
public static DeferredValue instance()
-
instance
public static DeferredValue instance(Object originalValue)
-
-