Package com.hubspot.jinjava.util
Class EagerContextWatcher.EagerChildContextConfig.Builder
java.lang.Object
com.hubspot.jinjava.util.EagerContextWatcher.EagerChildContextConfig.Builder
- Enclosing class:
EagerContextWatcher.EagerChildContextConfig
-
Method Summary
Modifier and TypeMethodDescriptionbuild()withCheckForContextChanges(boolean checkForContextChanges) withDiscardSessionBindings(boolean discardSessionBindings) withForceDeferredExecutionMode(boolean forceDeferredExecutionMode) withPartialMacroEvaluation(boolean partialMacroEvaluation) withTakeNewValue(boolean takeNewValue)
-
Method Details
-
withTakeNewValue
- Parameters:
takeNewValue- If a value is updated (not replaced) either take the new value or take the previous value and put it into theEagerExecutionResult.prefixToPreserveState.
-
withDiscardSessionBindings
public EagerContextWatcher.EagerChildContextConfig.Builder withDiscardSessionBindings(boolean discardSessionBindings) - Parameters:
discardSessionBindings- Discard the session bindings from the child context created while executing the provided function.
-
withPartialMacroEvaluation
public EagerContextWatcher.EagerChildContextConfig.Builder withPartialMacroEvaluation(boolean partialMacroEvaluation) - Parameters:
partialMacroEvaluation- Allow macro functions to be partially evaluated rather than needing an explicit result during this render.
-
withCheckForContextChanges
public EagerContextWatcher.EagerChildContextConfig.Builder withCheckForContextChanges(boolean checkForContextChanges) - Parameters:
checkForContextChanges- Hash and serialize values on the context to determine if changes have been made to any values on the context.
-
withForceDeferredExecutionMode
public EagerContextWatcher.EagerChildContextConfig.Builder withForceDeferredExecutionMode(boolean forceDeferredExecutionMode) - Parameters:
forceDeferredExecutionMode- Start the evaluation of the specified function in deferred execution mode.
-
build
-